<?php

namespace Drupal\ultimate_table_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the ultimate table field widget.
 *
 * @FieldFormatter(
 *   id = "ultimate_table",
 *   label = @Translation("Ultimate table"),
 *   description = @Translation("Ultimate table default formatter."),
 *   field_types = {
 *     "ultimate_table"
 *   }
 * )
 */
class UltimateTableFieldFormatter extends FormatterBase {

  /**
   * Ultimate table cell field manager plugin.
   *
   * @var \Drupal\ultimate_table_field\UltimateTableCellFieldManager
   */
  protected $ultimateTableCellFieldManager;

  /**
   * Renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->ultimateTableCellFieldManager = $container->get('plugin.manager.ultimate_table_cell_field');
    $instance->renderer = $container->get('renderer');
    return $instance;
  }

  /**
   * {@inheritDoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];
    foreach ($items as $item) {
      $values = $item->value;
      $columns = $values['columns'] ?? [];
      $rows = $values['rows'] ?? [];
      foreach ($rows as &$row) {
        foreach ($row as $j => $items) {
          if ($j === 0) {
            continue;
          }
          foreach ($items as &$cell_item) {
            $cell_field_instance = $this->ultimateTableCellFieldManager->createInstance($cell_item['type']);
            $cell_item = $cell_field_instance->cellFieldFormatter($cell_item);
          }
          // @phpstan-ignore-next-line
          $row[$j] = $this->renderer->renderPlain($items);
        }
      }
      $elements[] = [
        '#type' => 'table',
        '#header' => $columns,
        '#rows' => $rows,
        '#empty' => t('No entries available'),
      ];
    }
    return $elements;
  }

}
